OC.L10N.register(
    "text",
    {
    "Text" : "Texti",
    "📝 Collaborative document editing" : "📝 Samstarfsforrit til vinnslu skjala",
    "Use current version" : "Nota fyrirliggjandi útgáfu",
    "Use the saved version" : "Nota vistuðu útgáfuna",
    "Retry" : "Reyna aftur",
    "Last save {lastSave}" : "Síðast vistað {lastSave}",
    "Unsaved changes" : "Óvistaðar breytingar",
    "Edit guest name" : "Breyta nafni gests",
    "Save guest name" : "Vista nafn gests",
    "Insert image" : "Setja inn mynd",
    "Add link" : "Bæta við tengli",
    "Show image" : "Birta mynd",
    "Show file" : "Sýna skrá",
    "New text document" : "Nýtt textaskjal",
    "Edit" : "Breyta",
    "Undo" : "Afturkalla",
    "Redo" : "Endurtaka",
    "Bold" : "Feitletrað",
    "Italic" : "Skáletrað",
    "Strikethrough" : "Gegnumstrikað",
    "Paragraph" : "Málsgrein",
    "Headings" : "Fyrirsagnir",
    "Heading 1" : "Fyrirsögn 1",
    "Heading 2" : "Fyrirsögn 2",
    "Heading 3" : "Fyrirsögn 3",
    "Heading 4" : "Fyrirsögn 4",
    "Heading 5" : "Fyrirsögn 5",
    "Heading 6" : "Fyrirsögn 6",
    "Unordered list" : "Óraðaður listi",
    "Ordered list" : "Raðaður listi",
    "Blockquote" : "Tilvitnun",
    "Code block" : "Kóðablokk",
    "New text document.md" : "Nýtt textaskjal.md"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
